<?php

namespace App\Repository;

use App\Entity\EventLog\EventSource;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @method EventSource|null find($id, $lockMode = null, $lockVersion = null)
 * @method EventSource|null findOneBy(array $criteria, array $orderBy = null)
 * @method EventSource[]    findAll()
 * @method EventSource[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class EventSourceRepository extends ServiceEntityRepository
{

    /**
     * @param ManagerRegistry $registry
     */
    public function __construct(ManagerRegistry $registry){

        parent::__construct($registry, EventSource::class);

    }

}